/*******************************************************************************************************************************
Program: 				Child Analysis Merged Data.do
Purpose: 				This file creates the compiled versions of datafiles for our Child level analysis

Input Data:				hrdata_clean.dta (created in HR Data Cleaning.do)
						prdata_clean.dta (created in PR Data Cleaning.do)
						krdata_clean.dta (created in KR Data Cleaning.do)

Outputs:				child_stunting_analysis.dta
						child_diet_analysis.dta

Author: 				Eugene Lee, Anthony Leegwater
*******************************************************************************************************************************/

clear

** Merge Child code with Household data

* prep household (HR) file for merging
** stunting vars are from PR
use "${clean}\hrdata_clean.dta"

rename hv001 cluster_line
rename hv002 hh_line
*drop _merge

describe

tempfile hrtemp
save "`hrtemp'"

* create child stunting analysis file
** stunting vars are from PR
use "${clean}\prdata_clean.dta"

rename hv001 cluster_line
rename hv002 hh_line


* keep only children 0-59 months
keep if hc1<60

* keep only relevant vars
keep cluster_line hh_line nt_ch_stunt nt_ch_sev_stunt nt_ch_mean_haz nt_ch_wast nt_ch_sev_wast nt_ch_underwt nt_ch_sev_underwt

tempfile prtemp
save "`prtemp'"

merge m:1 cluster_line hh_line using "`hrtemp'"

keep if _merge==3
drop _merge

** Save for Child Stunting Analysis program
save "${clean}\child_stunting_analysis", replace

** key variables come from children born to interviewed mothers file (KR)
use "${clean}\krdata_clean.dta"

rename v001 cluster_line
rename v002 hh_line

* merge with main HH file
merge m:1 cluster_line hh_line using "`hrtemp'"

keep if _merge==3
drop _merge
** Save for Child MAL Analysis program
save "${clean}\child_diet_analysis", replace
