/*******************************************************************************************************************************
Program: 				PR DATA cleaning.do
Purpose: 				Clean DHS raw data at the Household Memeber level and create variables that are necessary

Input Data: 			MDPR81FL.DTA (Madagascar: Standard DHS, 2021)

Outputs:				prdata_clean.dta

Author: 				Anthony Leegwater, Eugene Lee, Sara Sokolinski
*******************************************************************************************************************************/

use "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\USAID Programs (Cleaned)\0.Raw data\MDPR81FL.dta", clear 

count 

************************************************************
* CHECK VALUES of variables
************************************************************

** socio-economic: malnutrition
summ hc1 hc70 hc71 hc72 hv103

************************************************************
* CONSTRUCT VARIABLES
************************************************************
label define noyes 0 "No" 1 "Yes", replace


** socio-economic: malnutrition**
**Calculate Weight 
gen wt=hv005/1000000

**Severely stunted
gen nt_ch_sev_stunt= 0 if hv103==1
replace nt_ch_sev_stunt=. if hc70>=9996
replace nt_ch_sev_stunt=1 if hc70<-300 & hv103==1 
label values nt_ch_sev_stunt noyes
label var nt_ch_sev_stunt "Severely stunted child under 5 years"

**Stunted
gen nt_ch_stunt= 0 if hv103==1
replace nt_ch_stunt=. if hc70>=9996
replace nt_ch_stunt=1 if hc70<-200 & hv103==1 
label values nt_ch_stunt noyes
label var nt_ch_stunt "Stunted child under 5 years"

**Mean haz
gen haz=hc70/100 if hc70<996
summarize haz if hv103==1 [iw=wt]
gen nt_ch_mean_haz=round(r(mean),0.1)
label var nt_ch_mean_haz "Mean z-score for height-for-age for children under 5 years"

**Severely wasted 
gen nt_ch_sev_wast= 0 if hv103==1
replace nt_ch_sev_wast=. if hc72>=9996
replace nt_ch_sev_wast=1 if hc72<-300 & hv103==1 
label values nt_ch_sev_wast noyes
label var nt_ch_sev_wast "Severely wasted child under 5 years"

**Wasted
gen nt_ch_wast= 0 if hv103==1
replace nt_ch_wast=. if hc72>=9996
replace nt_ch_wast=1 if hc72<-200 & hv103==1 
label values nt_ch_wast noyes
label var nt_ch_wast "Wasted child under 5 years"

**Overweight for height
gen nt_ch_ovwt_ht= 0 if hv103==1
replace nt_ch_ovwt_ht=. if hc72>=9996
replace nt_ch_ovwt_ht=1 if hc72>200 & hc72<9996 & hv103==1 
label values nt_ch_ovwt_ht noyes
label var nt_ch_ovwt_ht "Overweight for height child under 5 years"

**Mean whz
gen whz=hc72/100 if hc72<996
summarize whz if hv103==1 [iw=wt]
gen nt_ch_mean_whz=round(r(mean),0.1)
label var nt_ch_mean_whz "Mean z-score for weight-for-height for children under 5 years"

**Severely underweight
gen nt_ch_sev_underwt= 0 if hv103==1
replace nt_ch_sev_underwt=. if hc71>=9996
replace nt_ch_sev_underwt=1 if hc71<-300 & hv103==1 
label values nt_ch_sev_underwt noyes
label var nt_ch_sev_underwt	"Severely underweight child under 5 years"

**Underweight
gen nt_ch_underwt= 0 if hv103==1
replace nt_ch_underwt=. if hc71>=9996
replace nt_ch_underwt=1 if hc71<-200 & hv103==1 
label values nt_ch_underwt noyes
label var nt_ch_underwt "Underweight child under 5 years"

**Overweight for age
gen nt_ch_ovwt_age= 0 if hv103==1
replace nt_ch_ovwt_age=. if hc71>=9996
replace nt_ch_ovwt_age=1 if hc71>200 & hc71<9996 & hv103==1 
label values nt_ch_ovwt_age noyes
label var nt_ch_ovwt_age "Overweight for age child under 5 years"

**Mean waz
gen waz=hc71/100 if hc71<996
summarize waz if hv103==1 [iw=wt]
gen nt_ch_mean_waz=round(r(mean),0.1)
label var nt_ch_mean_waz "Mean weight-for-age for children under 5 years"

************************************************************
* Save the new dataset:
************************************************************
*Keep statement to reduce the datafile size:
keep hv001 hv002 hc1 hc70 hc71 hc72 hv103 wt nt_ch_sev_stunt nt_ch_stunt haz nt_ch_mean_haz nt_ch_sev_wast nt_ch_wast nt_ch_ovwt_ht whz nt_ch_mean_whz nt_ch_sev_underwt nt_ch_underwt nt_ch_ovwt_age waz nt_ch_mean_waz


* Save the new dataset:
save "${clean}\prdata_clean.dta", replace